﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

// Add a reference to:
//      Microsoft Word 14.0 Object Library

using Word = Microsoft.Office.Interop.Word;

namespace howto_list_words_with_style
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        // Let the user pick a file.
        private void btnPickFile_Click(object sender, EventArgs e)
        {
            ofdFile.FileName = txtFile.Text;
            if (ofdFile.ShowDialog() == DialogResult.OK)
            {
                txtFile.Text = ofdFile.FileName;
            }
        }

        // List the words in the file.
        private void btnListWords_Click(object sender, EventArgs e)
        {
            lstWords.DataSource = null;
            Cursor = Cursors.WaitCursor;
            Refresh();

            // Get the words.
            List<string> words = FindWordsWithStyle(txtFile.Text, txtStyle.Text);

            // Display the result.
            lstWords.DataSource = words;
            lblSummary.Text = words.Count + " words";
            Cursor = Cursors.Default;
        }

        // Find words with the given style in the Word file.
        private List<string> FindWordsWithStyle(string file_name, string word_style)
        {
            // Get the Word application object.
            Word._Application word_app = new Word.ApplicationClass();

            // Make Word visible (optional).
            word_app.Visible = false;

            // Open the file.
            object filename = file_name;
            object confirm_conversions = false;
            object read_only = true;
            object add_to_recent_files = false;
            object format = 0;
            object missing = System.Reflection.Missing.Value;

            Word._Document word_doc =
                word_app.Documents.Open(ref filename, ref confirm_conversions,
                    ref read_only, ref add_to_recent_files,
                    ref missing, ref missing, ref missing, ref missing,
                    ref missing, ref format, ref missing, ref missing,
                    ref missing, ref missing, ref missing, ref missing);

            // Search.
            List<string> result = new List<string>();
            object style = word_style;
            word_app.Selection.Find.ClearFormatting();
            word_app.Selection.Find.set_Style(ref style);
            object obj_true = true;
            for (;;)
            {
                word_app.Selection.Find.Execute(ref missing,
                    ref missing, ref missing, ref missing, ref missing,
                    ref missing, ref missing, ref missing, ref obj_true,
                    ref missing, ref missing, ref missing, ref missing,
                    ref missing, ref missing);
                if (!word_app.Selection.Find.Found) break;
                result.Add(word_app.Selection.Text);
            }

            // Close the document without prompting.
            object save_changes = false;
            word_doc.Close(ref save_changes, ref missing, ref missing);
            word_app.Quit(ref save_changes, ref missing, ref missing);

            // Return the result.
            return result;
        }
    }
}
